@@ -29,9 +29,9 @@
 #include "config.h"
 #endif
 
-#include "xine_internal.h"
-#include "post.h"
-#include "xineutils.h"
+#include <xine/xine_internal.h>
+#include <xine/post.h>
+#include <xine/xineutils.h>
 #include <math.h>
 #include <pthread.h>
 
@@ -393,9 +393,6 @@ static xine_post_api_t post_api = {
 static post_plugin_t *eq2_open_plugin(post_class_t *class_gen, int inputs,
 					 xine_audio_port_t **audio_target,
 					 xine_video_port_t **video_target);
-static char          *eq2_get_identifier(post_class_t *class_gen);
-static char          *eq2_get_description(post_class_t *class_gen);
-static void           eq2_class_dispose(post_class_t *class_gen);
 
 /* plugin instance functions */
 static void           eq2_dispose(post_plugin_t *this_gen);
@@ -413,15 +410,15 @@ static int            eq2_draw(vo_frame_t *frame, xine_stream_t *stream);
 
 void *eq2_init_plugin(xine_t *xine, void *data)
 {
-  post_class_t *class = (post_class_t *)malloc(sizeof(post_class_t));
+  post_class_t *class = (post_class_t *)xine_xmalloc(sizeof(post_class_t));
 
   if (!class)
     return NULL;
 
   class->open_plugin     = eq2_open_plugin;
-  class->get_identifier  = eq2_get_identifier;
-  class->get_description = eq2_get_description;
-  class->dispose         = eq2_class_dispose;
+  class->identifier      = "eq2";
+  class->description     = N_("Software video equalizer");
+  class->dispose         = default_post_class_dispose;
 
   return class;
 }
@@ -480,22 +477,6 @@ static post_plugin_t *eq2_open_plugin(post_class_t *class_gen, int inputs,
   return &this->post;
 }
 
-static char *eq2_get_identifier(post_class_t *class_gen)
-{
-  return "eq2";
-}
-
-static char *eq2_get_description(post_class_t *class_gen)
-{
-  return "Software video equalizer";
-}
-
-static void eq2_class_dispose(post_class_t *class_gen)
-{
-  free(class_gen);
-}
-
-
 static void eq2_dispose(post_plugin_t *this_gen)
 {
   post_plugin_eq2_t *this = (post_plugin_eq2_t *)this_gen;
