@@ -39,8 +39,9 @@
 #define LOG
 */
 
-#include "xine_internal.h"
-#include "xineutils.h"
+#include <xine/xine_internal.h>
+#include <xine/xineutils.h>
+#include "xine_private.h"
 
 static void *audio_decoder_loop (void *stream_gen) {
 
@@ -466,7 +467,7 @@ static void *audio_decoder_loop (void *stream_gen) {
 int _x_audio_decoder_init (xine_stream_t *stream) {
 
   pthread_attr_t       pth_attrs;
-#if defined(_POSIX_THREAD_PRIORITY_SCHEDULING) && (_POSIX_THREAD_PRIORITY_SCHEDULING > 0)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
   struct sched_param   pth_params;
 #endif
   int                  err;
@@ -506,7 +507,7 @@ int _x_audio_decoder_init (xine_stream_t *stream) {
      */
 
     pthread_attr_init(&pth_attrs);
-#if defined(_POSIX_THREAD_PRIORITY_SCHEDULING) && (_POSIX_THREAD_PRIORITY_SCHEDULING > 0)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
     pthread_attr_getschedparam(&pth_attrs, &pth_params);
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
