@@ -36,8 +36,9 @@
 #define LOG
 */
 
-#include "xine_internal.h"
-#include "xineutils.h"
+#include <xine/xine_internal.h>
+#include <xine/xineutils.h>
+#include "xine_private.h"
 #include <sched.h>
 
 #define SPU_SLEEP_INTERVAL (90000/2)
@@ -96,7 +97,7 @@ int _x_spu_decoder_sleep(xine_stream_t *stream, int64_t next_spu_vpts)
       thread_vacant = (stream->video_fifo->first->type != BUF_CONTROL_FLUSH_DECODER);
     /* we have to return if the demuxer needs us to release a buffer */
     if (thread_vacant)
-      thread_vacant = !stream->demux_action_pending;
+      thread_vacant = !_x_action_pending(stream);
 
   } while (wait == SPU_SLEEP_INTERVAL && thread_vacant);
 
@@ -518,7 +519,7 @@ int _x_video_decoder_init (xine_stream_t *stream) {
   } else {
 
     pthread_attr_t       pth_attrs;
-#if defined(_POSIX_THREAD_PRIORITY_SCHEDULING) && (_POSIX_THREAD_PRIORITY_SCHEDULING > 0)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
     struct sched_param   pth_params;
 #endif
     int		       err, num_buffers;
@@ -549,7 +550,7 @@ int _x_video_decoder_init (xine_stream_t *stream) {
     stream->spu_track_map_entries = 0;
 
     pthread_attr_init(&pth_attrs);
-#if defined(_POSIX_THREAD_PRIORITY_SCHEDULING) && (_POSIX_THREAD_PRIORITY_SCHEDULING > 0)
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
     pthread_attr_getschedparam(&pth_attrs, &pth_params);
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
